#[repr(u8)]pub enum Cmp1f {
CMP1F0 = 0,
CMP1F1 = 1,
}Variants
CMP1F0 = 0
When the position counter is less than value of COMP1 register
CMP1F1 = 1
When the position counter is greater or equal than value of COMP1 register
Implementations