#[repr(u8)]pub enum Cmp2f {
CMP2F0 = 0,
CMP2F1 = 1,
}Variants
CMP2F0 = 0
When the position counter is less than value of COMP2 register
CMP2F1 = 1
When the position counter is greater or equal than value of COMP2 register
Implementations