#[repr(u8)]pub enum Cmp3f {
CMP3F0 = 0,
CMP3F1 = 1,
}Variants
CMP3F0 = 0
When the position counter value is less than value of COMP3 register
CMP3F1 = 1
When the position counter is greater or equal than value of COMP3 register
Implementations