#[repr(u8)]pub enum Cmpf0 {
CMPF00 = 0,
CMPF01 = 1,
}Variants
CMPF00 = 0
When the position counter is less than value of COMP0 register
CMPF01 = 1
When the position counter is greater or equal than value of COMP0 register
Implementations