#[repr(u8)]pub enum Emip {
EMIP0 = 0,
EMIP1 = 1,
}Variants
EMIP0 = 0
disables the position counter to be initialized by Index Event Edge Mark
EMIP1 = 1
enables the position counter to be initialized by Index Event Edge Mark.
Implementations