#[repr(u8)]pub enum Ldmod {
LDMOD0 = 0,
LDMOD1 = 1,
}Variants
LDMOD0 = 0
Buffered registers are loaded and take effect immediately upon CTRL[LDOK] is set.
LDMOD1 = 1
Buffered registers are loaded and take effect at the next roll-over or roll-under if CTRL[LDOK] is set.
Implementations