#[repr(u8)]pub enum Ldok {
LDOK0 = 0,
LDOK1 = 1,
}Variants
LDOK0 = 0
No loading action taken. Users can write new values to buffered registers (writing into outer-set of these buffered registers)
LDOK1 = 1
Outer-set values are ready to be loaded into inner-set and take effect. The loading time point depends on CTRL2[LDMOD].
Implementations