#[repr(u8)]pub enum Outctl {
OUTCTL0 = 0,
OUTCTL1 = 1,
}Variants
OUTCTL0 = 0
POS_MATCH[x](x range is 0-3) is asserted when the Position Counter is equal to according compare value (UCOMPx/LCOMPx)(x range is 0-3), and de-asserted when the Position Counter not equal to the compare value (UCOMPx/LCOMPx)(x range is 0-3)
OUTCTL1 = 1
All POS_MATCH[x](x range is 0-3) are asserted a pulse, when the UPOS, LPOS, REV, or POSD registers are read
Implementations