#[repr(u8)]pub enum Rev {
REV0 = 0,
REV1 = 1,
}Variants
REV0 = 0
Count normally and the position counter initialization uses upper/lower initialization register UINIT/LINIT
REV1 = 1
Count in the reverse direction and the position counter initialization uses upper/lower modulus register UMOD/LMOD
Implementations